"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _contains = _interopRequireDefault(require("dom-helpers/contains"));

/**
 * @file Dom vendor
 * @author liangxiaojun(liangxiaojun@derbysoft.com)
 */
function getOffset(el) {
  var parentEl = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : document.body;

  if (!el) {
    return null;
  }

  var offset = {
    top: el.offsetTop,
    left: el.offsetLeft
  }; // handle offset

  var offsetParent = el.offsetParent;

  while (offsetParent) {
    if (parentEl && offsetParent.contains(parentEl)) {
      break;
    } // append layout offset


    offset.top += offsetParent.offsetTop;
    offset.left += offsetParent.offsetLeft; // append transform offset

    var transform = window.getComputedStyle(offsetParent).transform,
        matched = transform.match(/^matrix\((.*)\)$/);

    if (matched && matched[1]) {
      var matrix = matched[1].split(/\s*,\s*/);
      offset.top += +matrix[5];
      offset.left += +matrix[4];
    }

    offsetParent = offsetParent.offsetParent;
  } // handle scroll


  var scrollParent = getClosestScrollable(el.parentElement);

  while (scrollParent) {
    if (parentEl && scrollParent.contains(parentEl)) {
      break;
    } // drop scroll offset


    offset.top -= scrollParent.scrollTop;
    offset.left -= scrollParent.scrollLeft;
    scrollParent = getClosestScrollable(scrollParent.parentElement);
  }

  return offset;
}

function getScrollHeight() {
  return document.body.scrollHeight || document.documentElement.scrollHeight;
}

function getScrollLeft(parentEl) {
  if (window.SCROLL_EL && window.SCROLL_EL.scrollLeft) {
    return SCROLL_EL.scrollLeft;
  }

  if (parentEl && parentEl !== document.body) {
    return parentEl.scrollLeft;
  }

  return document.body.scrollLeft || document.documentElement.scrollLeft;
}

function getScrollTop(parentEl) {
  if (window.SCROLL_EL && window.SCROLL_EL.scrollTop) {
    return SCROLL_EL.scrollTop;
  }

  if (parentEl && parentEl !== document.body) {
    return parentEl.scrollTop;
  }

  return document.body.scrollTop || document.documentElement.scrollTop;
}

function hasClass(el, className) {
  if (!el || !className) {
    return false;
  }

  var elClassName = el.className;

  if (!elClassName) {
    return false;
  }

  var elClass = elClassName.split(/\s+/);
  return elClass && elClass.findIndex(function (item) {
    return item === className;
  }) !== -1;
}

function addClass(el, className) {
  if (!el || !className) {
    return;
  }

  var elClassName = el.className;

  if (!elClassName) {
    el.className = className;
    return;
  }

  var elClass = elClassName.split(/\s+/),
      index = elClass ? elClass.findIndex(function (item) {
    return item === className;
  }) : -1;

  if (index !== -1) {
    // already has this className
    return;
  }

  elClass.push(className);
  el.className = elClass.join(' ');
}

function removeClass(el, className) {
  if (!el || !className) {
    return;
  }

  var elClassName = el.className;

  if (!elClassName) {
    return;
  }

  var elClass = elClassName.split(/\s+/),
      index = elClass ? elClass.findIndex(function (item) {
    return item === className;
  }) : -1;

  if (index === -1) {
    // no this className
    return;
  }

  elClass.splice(index, 1);
  el.className = elClass.join(' ');
}

function toggleClass(el, className, bool) {
  bool ? addClass(el, className) : removeClass(el, className);
}

function findParentByClassName(el, className) {
  if (!el || !className) {
    return;
  }

  while (el) {
    if (hasClass(el, className)) {
      return el;
    }

    el = el.parentNode;
  }

  return;
}

function isParent(el, parentEl) {
  if (!el || !parentEl) {
    return false;
  }

  do {
    el = el.parentNode;

    if (el == parentEl) {
      return true;
    }
  } while (el);

  return false;
}

function isScrollable() {
  for (var _len = arguments.length, values = new Array(_len), _key = 0; _key < _len; _key++) {
    values[_key] = arguments[_key];
  }

  return values.some(function (value) {
    return value === 'auto' || value === 'scroll';
  });
}

function isElementScrollable(el) {
  var style = window.getComputedStyle(el);
  return isScrollable(style.overflow, style.overflowY, style.overflowX);
}

;

function getClosestScrollable(el) {
  if (el == null) {
    return null;
  }

  if (!isElementScrollable(el)) {
    return getClosestScrollable(el.parentElement);
  }

  return el;
}

function getTotalScrollOffset(el) {
  var scrollEl = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : document.body;
  var result = {
    left: 0,
    top: 0
  };

  if (!el || !scrollEl) {
    return result;
  }

  while (el && (0, _contains["default"])(scrollEl, el)) {
    result.left += el.scrollLeft;
    result.top += el.scrollTop;
    el = el.parentElement;
  }

  return result;
}

function isElementFixed(el) {
  return window.getComputedStyle(el).position === 'fixed';
}

;

function getClosestFixed(el) {
  if (el == null) {
    return null;
  }

  if (!isElementFixed(el)) {
    return getClosestFixed(el.parentElement);
  }

  return el;
}

var _default = {
  getOffset: getOffset,
  getScrollHeight: getScrollHeight,
  getScrollLeft: getScrollLeft,
  getScrollTop: getScrollTop,
  hasClass: hasClass,
  addClass: addClass,
  removeClass: removeClass,
  toggleClass: toggleClass,
  findParentByClassName: findParentByClassName,
  isParent: isParent,
  isScrollable: isScrollable,
  isElementScrollable: isElementScrollable,
  getClosestScrollable: getClosestScrollable,
  getTotalScrollOffset: getTotalScrollOffset,
  isElementFixed: isElementFixed,
  getClosestFixed: getClosestFixed
};
exports["default"] = _default;