"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;

var _isArray = _interopRequireDefault(require("lodash/isArray"));

var _isNumber = _interopRequireDefault(require("lodash/isNumber"));

var _FieldType = _interopRequireDefault(require("../_statics/FieldType"));

/**
 * @file Valid vendor
 * @author liangxiaojun(liangxiaojun@derbysoft.com)
 */
function range(value, min, max) {
  max !== undefined && (value = value > max ? max : value);
  min !== undefined && (value = value < min ? min : value);
  return value;
}

function isChrome() {
  return /chrome/i.test(navigator.userAgent);
}

function isMac() {
  return /macintosh|mac os x/i.test(navigator.userAgent);
}

function isWindows() {
  return /windows|win32/i.test(navigator.userAgent);
}

function isInteger(value) {
  return /^(0|-?[0-9][1-9]*)$/.test(value);
}

function isPositiveInteger(value) {
  return isInteger(value) && value > 0;
}

function isNonnegativeInteger(value) {
  return isInteger(value) && value >= 0;
}

function isNegativeInteger(value) {
  return isInteger(value) && value < 0;
}

function isNonpositiveInteger(value) {
  return isInteger(value) && value <= 0;
}

function isOdd(value) {
  return isInteger(value) && value % 2 === 1;
}

function isEven(value) {
  return isInteger(value) && value % 2 === 0;
}

function isInRange(value, min, max) {
  return (0, _isNumber["default"])(value) && (0, _isNumber["default"])(min) && (0, _isNumber["default"])(max) && value >= min && value <= max;
}

function isEmail(value) {
  return /^\w[-\w.+]*@([A-Za-z0-9][-A-Za-z0-9]+\.)+[A-Za-z]{2,14}$/.test(value);
}

function isUrl(value) {
  return /^((https|http|ftp|rtsp|mms)?:\/\/)[^\s]+$/.test(value);
}

function isPerCent(perCent) {
  return (0, _isNumber["default"])(perCent) && perCent >= 0 && perCent <= 1;
}

function isDeg(deg) {
  return (0, _isNumber["default"])(deg) && deg >= 0 && deg <= 360;
}

function isRGB(rgb) {
  return rgb && (0, _isArray["default"])(rgb) && rgb.length === 3 && rgb.filter(function (item) {
    return item >= 0 && item <= 255;
  }).length === 3;
}

function isHSB(hsb) {
  return hsb && (0, _isArray["default"])(hsb) && hsb.length === 3 && isDeg(hsb[0]) && isInRange(hsb[1], 0, 1) && isInRange(hsb[2], 0, 1);
}

function isHex(hex) {
  var hasHash = hex[0] === '#';

  if (!hex) {
    return false;
  }

  if (!hasHash && hex.length !== 6 || hasHash && hex.length !== 7) {
    return false;
  }

  if (hasHash && hex[0] !== '#') {
    return false;
  }

  function fn(i) {
    var j = hasHash ? 1 : 0;
    return isInRange(parseInt(hex.slice(i + j, i + j + 2), 16), 0, 255);
  }

  return fn(0) && fn(2) && fn(4);
}

function isNumberType(type) {
  var NUMBER = _FieldType["default"].NUMBER,
      INTEGER = _FieldType["default"].INTEGER,
      POSITIVE_INTEGER = _FieldType["default"].POSITIVE_INTEGER,
      NONNEGATIVE_INTEGER = _FieldType["default"].NONNEGATIVE_INTEGER,
      NEGATIVE_INTEGER = _FieldType["default"].NEGATIVE_INTEGER,
      NONPOSITIVE_INTEGER = _FieldType["default"].NONPOSITIVE_INTEGER;
  return type === NUMBER || type === INTEGER || type === POSITIVE_INTEGER || type === NONNEGATIVE_INTEGER || type === NEGATIVE_INTEGER || type === NONPOSITIVE_INTEGER;
}

function fieldValid(value, props) {
  var type = props.type,
      required = props.required,
      maxLength = props.maxLength,
      max = props.max,
      min = props.min,
      pattern = props.pattern,
      patternInvalidMsg = props.patternInvalidMsg;
  var invalidMsgs = [];

  if (required === true && value === '') {
    invalidMsgs.push('Required');
  }

  if (type === _FieldType["default"].EMAIL && value && !isEmail(value)) {
    invalidMsgs.push('Invalid E-mail address');
  }

  if (type === _FieldType["default"].URL && value && !isUrl(value)) {
    invalidMsgs.push('Invalid url');
  }

  if (maxLength !== undefined && !isNaN(maxLength) && maxLength > 0 && value && value.length > maxLength) {
    invalidMsgs.push("Max length is ".concat(maxLength));
  }

  if (isNumberType(type) && value) {
    if (type === _FieldType["default"].NUMBER && !(0, _isNumber["default"])(value)) {
      invalidMsgs.push('Not a valid number');
    }

    if (type === _FieldType["default"].INTEGER && !isInteger(value)) {
      invalidMsgs.push('Not a valid integer');
    }

    if (type === _FieldType["default"].POSITIVE_INTEGER && !isPositiveInteger(value)) {
      invalidMsgs.push('Not a valid positive integer');
    }

    if (type === _FieldType["default"].NONNEGATIVE_INTEGER && !isNonnegativeInteger(value)) {
      invalidMsgs.push('Not a valid nonnegative integer');
    }

    if (type === _FieldType["default"].NEGATIVE_INTEGER && !isNegativeInteger(value)) {
      invalidMsgs.push('Not a valid negative integer');
    }

    if (type === _FieldType["default"].NONPOSITIVE_INTEGER && !isNonpositiveInteger(value)) {
      invalidMsgs.push('Not a valid nonpositive integer');
    }

    if (max !== undefined && value > max) {
      invalidMsgs.push("Maximum value is ".concat(max));
    }

    if (min !== undefined && value < min) {
      invalidMsgs.push("Minimum value is ".concat(min));
    }
  }

  if (pattern !== undefined && !pattern.test(value)) {
    invalidMsgs.push(patternInvalidMsg);
  }

  return invalidMsgs;
}

var _default = {
  range: range,
  isChrome: isChrome,
  isMac: isMac,
  isWindows: isWindows,
  isInteger: isInteger,
  isPositiveInteger: isPositiveInteger,
  isNonnegativeInteger: isNonnegativeInteger,
  isNegativeInteger: isNegativeInteger,
  isNonpositiveInteger: isNonpositiveInteger,
  isOdd: isOdd,
  isEven: isEven,
  isInRange: isInRange,
  isEmail: isEmail,
  isUrl: isUrl,
  isPerCent: isPerCent,
  isDeg: isDeg,
  isRGB: isRGB,
  isHSB: isHSB,
  isHex: isHex,
  isNumberType: isNumberType,
  fieldValid: fieldValid
};
exports["default"] = _default;